@@ -5,7 +5,7 @@ use utf8;
 
 package Dist::Zilla::Plugin::MetaData::BuiltWith;
 
-our $VERSION = '1.003001';
+our $VERSION = '1.004000';
 
 # ABSTRACT: Report what versions of things your distribution was built against
 
@@ -20,7 +20,9 @@ use Dist::Zilla::Util::ConfigDumper qw( config_dumper );
 use Module::Runtime qw( is_module_name );
 use Devel::CheckBin qw( can_run );
 use namespace::autoclean;
+with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::FileMunger';
+with 'Dist::Zilla::Role::MetaProvider';
 
 
 
@@ -116,8 +118,61 @@ has _uname_args => (
 );
 has _stash_key => ( is => 'ro', isa => Str, default => 'x_BuiltWith' );
 
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+has 'use_external_file' => (
+  is         => 'ro',
+  lazy_build => 1,
+);
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+has 'external_file_name' => (
+  is         => 'ro',
+  isa        => Str,
+  lazy_build => 1,
+);
+
 around dump_config => config_dumper( __PACKAGE__,
-  qw( show_uname _stash_key show_config ),
+  qw( show_uname _stash_key show_config use_external_file external_file_name ),
   sub {
     my ( $self, $payload ) = @_;
     if ( $self->show_uname ) {
@@ -188,6 +243,24 @@ sub _build__uname_args {
   return [ grep { defined $_ && $_ ne q{} } split /\s+/, $self->uname_args ];
 }
 
+sub _build_use_external_file {
+  return;
+}
+
+sub _build_external_file_name {
+  return 'misc/built_with.json';
+}
+
+
+
+
+
+sub metadata {
+  my ($self) = @_;
+  return {} unless 'only' eq ( $self->use_external_file || q[] );
+  return { $self->_stash_key, { external_file => $self->external_file_name }, };
+}
+
 sub _get_prereq_modnames {
   my ($self) = @_;
 
@@ -315,11 +388,58 @@ sub _metadata {
   return $result;
 }
 
+
+
+
+
+sub gather_files {
+  my ($self) = @_;
+
+  return unless $self->use_external_file;
+
+  my $type =
+      $self->external_file_name =~ /[.]json\z/msix  ? 'JSON'
+    : $self->external_file_name =~ /[.]ya?ml\z/msix ? 'YAML'
+    :                                                 croak 'Cant guess file type for ' . $self->external_file_name;
+
+  my $code;
+
+  if ( 'JSON' eq $type ) {
+    require JSON::MaybeXS;
+    require Dist::Zilla::File::FromCode;
+    my $json = JSON::MaybeXS->new;
+    $json->pretty(1);
+    $json->canonical(1);
+    $json->convert_blessed(1);
+    $json->allow_blessed(1);
+    $code = sub {
+      return $json->encode( $self->_metadata );
+    };
+  }
+  if ( 'YAML' eq $type ) {
+    require YAML::Tiny;
+    $code = sub {
+      return YAML::Tiny::Dump( $self->_metadata );
+    };
+  }
+
+  $self->add_file(
+    Dist::Zilla::File::FromCode->new(
+      name             => $self->external_file_name,
+      code             => $code,
+      code_return_type => 'text',
+    ),
+  );
+  return;
+}
+
 sub munge_files {
   my ($self) = @_;
 
   my $munged = {};
 
+  return if 'only' eq ( $self->use_external_file || q[] );
+
   for my $file ( @{ $self->zilla->files } ) {
     if ( 'META.json' eq $file->name ) {
       require JSON::MaybeXS;
@@ -379,17 +499,18 @@ Dist::Zilla::Plugin::MetaData::BuiltWith - Report what versions of things your d
 
 =head1 VERSION
 
-version 1.003001
+version 1.004000
 
 =head1 SYNOPSIS
 
   [MetaData::BuiltWith]
   include = Some::Module::Thats::Not::In::Preq
   exclude = Some::Module::Youre::Ashamed::Of
-  show_uname = 1           ; default is 0
-  show_config = 1          ; default is 0
-  uname_call = uname        ; the default
-  uname_args = -s -r -m -p  ; the default is -a
+  show_uname = 1             ; default is 0
+  show_config = 1            ; default is 0
+  uname_call = uname         ; the default
+  uname_args = -s -r -m -p   ; the default is -a
+  use_external_file = only   ; the default is undef
 
 =head1 DESCRIPTION
 
@@ -443,6 +564,44 @@ Specify arguments passed to the C<uname> call.
 
     uname_args = -a ; String
 
+=head2 use_external_file
+
+This option regulates the optional output to an isolated file.
+
+An external file will be created as long as this value is a true value.
+
+  use_external_file = 1
+
+If this true value is the string C<only>, then it won't also be exported to META.yml/META.json
+
+  use_external_file = only
+
+NOTE:
+
+This will still leave an x_BuiltWith section in your META.*, however, its much less fragile
+and will simply be:
+
+   x_BuiltWith: {
+      external_file: "your/path/here"
+   }
+
+This is mostly a compatibility pointer so any tools traversing a distributions history will know where and when to change
+behavior.
+
+=head2 external_file_name
+
+This option controls what the external file will be called in conjunction with C<use_external_file>
+
+Default value is:
+
+  misc/built_with.json
+
+Extensions:
+
+  .json => JSON is used.
+  .yml  => YAML is used (untested)
+  .yaml => YAML is used (untested)
+
 =head1 METHODS
 
 =head2 mvp_multivalue_args
@@ -456,6 +615,10 @@ that Dist::Zilla collects, and then works out what version of things you have,
 applies the various include/exclude rules, and ships that data back to Dist::Zilla
 via this method. See L<< C<Dist::Zilla>'s C<MetaProvider> role|Dist::Zilla::Role::MetaProvider >> for more details.
 
+=for Pod::Coverage metadata
+
+=for Pod::Coverage gather_files
+
 =head1 EXAMPLE OUTPUT ( C<META.json> )
 
     "x_BuiltWith" : {
